\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ifd-thesis}[Student project report class.]


% base class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[11pt,a4paper]{article}


% packages
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[ngerman, english]{babel}
\RequirePackage{csquotes}
\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{graphicx}
\RequirePackage[parfill]{parskip}
\RequirePackage{geometry}
\RequirePackage[hidelinks]{hyperref}
\RequirePackage{pdfpages}
\RequirePackage[backend=bibtex]{biblatex}


% bump pdf version
\pdfminorversion=6


% page margins
\geometry{nomarginpar,a4paper,tmargin=20mm,bmargin=15mm,lmargin=25mm,rmargin=25mm,includeheadfoot,headheight=0mm}


% references *.bib file
\bibliography{references}


% title page parameters
\newcommand{\thesisTitleVar}{<title>}
\newcommand{\thesisStudentVar}{<author name>}
\newcommand{\thesisProgramVar}{<study program>}
\newcommand{\thesisYearVar}{<20YY>}
\newcommand{\thesisSemesterVar}{<HS/FS>}
\newcommand{\thesisTypeVar}{<project type>}
\newcommand{\thesisSupervisorVar}{<supervisor name>}
\newcommand{\thesisProfessorVar}{<professor name>}

\newcommand{\thesisTitle}[1]{\renewcommand{\thesisTitleVar}{#1}}
\newcommand{\thesisStudent}[1]{\renewcommand{\thesisStudentVar}{#1}}
\newcommand{\thesisProgram}[1]{\renewcommand{\thesisProgramVar}{#1}}
\newcommand{\thesisYear}[1]{\renewcommand{\thesisYearVar}{#1}}
\newcommand{\thesisSemester}[1]{\renewcommand{\thesisSemesterVar}{#1}}
\newcommand{\thesisType}[1]{\renewcommand{\thesisTypeVar}{#1}}
\newcommand{\thesisSupervisor}[1]{\renewcommand{\thesisSupervisorVar}{#1}}
\newcommand{\thesisProfessor}[1]{\renewcommand{\thesisProfessorVar}{#1}}

% title page
\renewcommand{\maketitle}{%
    \thispagestyle{empty}
    \begin{center}
        \vspace*{20mm}
        {\huge \textbf{\thesisTitleVar}}\\
        \vspace{20mm}
        {\large
            \thesisStudentVar\\
            ~\\
            \thesisProgramVar\\
            \vspace{35mm}
            \thesisTypeVar~\thesisSemesterVar~\thesisYearVar\\
            ~\\
            Institute of Fluid Dynamics\\
            ETH Zurich\\
        }
        \vspace{\stretch{1}}
        {\large
            Supervisor: \thesisSupervisorVar\\[\baselineskip]
            Professor: \thesisProfessorVar
        }
        \vspace*{40mm}
    \end{center}
}
